def sanitize(time_string):
    if '-' in time_string:
        splitter = '-'
    elif ':' in time_string:
        splitter = ':'
    else:
        return(time_string)
    (mins,secs) = time_string.split(splitter)
    return(mins+'.'+secs)

def get_coach_data(file_name):
    try:
        with open(file_name) as f:
            data = f.readline()
        return(data.strip().split(','))
    except IOError as err:
        print('File Error: ' + str(err))







from distutils.core import setup

setup(
	name			=	'CP6',
	version		    =	'1.0.0',
	py_modules		=	['CP6'],
	author			=	'Kevin Chen',
    author_email    =   'hchen66@ucsc.edu',
    url             =   'ucsc.edu',
	description		=	'CP6',
         )